# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/workflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import compiler_pb2 as flyteidl_dot_core_dot_compiler__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import workflow_pb2 as flyteidl_dot_core_dot_workflow__pb2
from flyteidl.admin import description_entity_pb2 as flyteidl_dot_admin_dot_description__entity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66lyteidl/admin/workflow.proto\x12\x0e\x66lyteidl.admin\x1a\x1c\x66lyteidl/core/compiler.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1c\x66lyteidl/core/workflow.proto\x1a\'flyteidl/admin/description_entity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"t\n\x15WorkflowCreateRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.flyteidl.admin.WorkflowSpecR\x04spec\"\x18\n\x16WorkflowCreateResponse\"\x9d\x01\n\x08Workflow\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12\x39\n\x07\x63losure\x18\x02 \x01(\x0b\x32\x1f.flyteidl.admin.WorkflowClosureR\x07\x63losure\x12+\n\x11short_description\x18\x03 \x01(\tR\x10shortDescription\"\\\n\x0cWorkflowList\x12\x36\n\tworkflows\x18\x01 \x03(\x0b\x32\x18.flyteidl.admin.WorkflowR\tworkflows\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"\xd6\x01\n\x0cWorkflowSpec\x12;\n\x08template\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.WorkflowTemplateR\x08template\x12\x44\n\rsub_workflows\x18\x02 \x03(\x0b\x32\x1f.flyteidl.core.WorkflowTemplateR\x0csubWorkflows\x12\x43\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32!.flyteidl.admin.DescriptionEntityR\x0b\x64\x65scription\"\xa1\x01\n\x0fWorkflowClosure\x12S\n\x11\x63ompiled_workflow\x18\x01 \x01(\x0b\x32&.flyteidl.core.CompiledWorkflowClosureR\x10\x63ompiledWorkflow\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"R\n%WorkflowErrorExistsDifferentStructure\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\"R\n%WorkflowErrorExistsIdenticalStructure\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\"\x95\x02\n\x1b\x43reateWorkflowFailureReason\x12u\n\x1a\x65xists_different_structure\x18\x01 \x01(\x0b\x32\x35.flyteidl.admin.WorkflowErrorExistsDifferentStructureH\x00R\x18\x65xistsDifferentStructure\x12u\n\x1a\x65xists_identical_structure\x18\x02 \x01(\x0b\x32\x35.flyteidl.admin.WorkflowErrorExistsIdenticalStructureH\x00R\x18\x65xistsIdenticalStructureB\x08\n\x06reasonB\xb3\x01\n\x12\x63om.flyteidl.adminB\rWorkflowProtoP\x01Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.workflow_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\rWorkflowProtoP\001Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_WORKFLOWCREATEREQUEST']._serialized_start=215
  _globals['_WORKFLOWCREATEREQUEST']._serialized_end=331
  _globals['_WORKFLOWCREATERESPONSE']._serialized_start=333
  _globals['_WORKFLOWCREATERESPONSE']._serialized_end=357
  _globals['_WORKFLOW']._serialized_start=360
  _globals['_WORKFLOW']._serialized_end=517
  _globals['_WORKFLOWLIST']._serialized_start=519
  _globals['_WORKFLOWLIST']._serialized_end=611
  _globals['_WORKFLOWSPEC']._serialized_start=614
  _globals['_WORKFLOWSPEC']._serialized_end=828
  _globals['_WORKFLOWCLOSURE']._serialized_start=831
  _globals['_WORKFLOWCLOSURE']._serialized_end=992
  _globals['_WORKFLOWERROREXISTSDIFFERENTSTRUCTURE']._serialized_start=994
  _globals['_WORKFLOWERROREXISTSDIFFERENTSTRUCTURE']._serialized_end=1076
  _globals['_WORKFLOWERROREXISTSIDENTICALSTRUCTURE']._serialized_start=1078
  _globals['_WORKFLOWERROREXISTSIDENTICALSTRUCTURE']._serialized_end=1160
  _globals['_CREATEWORKFLOWFAILUREREASON']._serialized_start=1163
  _globals['_CREATEWORKFLOWFAILUREREASON']._serialized_end=1440
# @@protoc_insertion_point(module_scope)
